@@ -7,12 +7,15 @@ use Scalar::Util qw( refaddr );
 Class::InsideOut::property my %name;
 Class::InsideOut::property my %species;
 
+our $animal_count;
+
 sub new {
     my $class = shift;
     my $self = bless \do {my $s}, $class;
     Class::InsideOut::register($self);
     $name{ refaddr $self } = undef;
     $species{ refaddr $self } = undef;
+    $animal_count++;
     return $self;
 }
 
@@ -28,4 +31,14 @@ sub species {
     return $species{ refaddr $self };
 }
 
+our @subclass_errors;
+
+sub DEMOLISH {
+    my $self = shift;
+    $animal_count--;
+    if ( ref $self ne "t::Object::Animal" ) {
+        push @subclass_errors, ref $self;
+    }
+}
+
 1;
